@@ -146,6 +146,19 @@ namespace OpenBabel
     return(NULL);
   }
 
+  std::vector<OBGenericData *> OBBase::GetAllData(const unsigned int dt)
+  {
+    std::vector<OBGenericData *> matches;
+    
+    // return all values matching this type
+    OBDataIterator i;
+    for (i = _vdata.begin();i != _vdata.end();++i)
+      if ((*i)->GetDataType() == dt)
+        matches.push_back(*i);
+        
+    return(matches);
+  }
+
   std::vector<OBGenericData*>  OBBase::GetData(DataOrigin source)
   {
     std::vector<OBGenericData*> filtered; // filtered data only from source
@@ -157,6 +170,20 @@ namespace OpenBabel
 
     return filtered;
   }
+  
+  void OBBase::CloneData(OBGenericData *d)
+  {
+    if(!d)
+      return; // Nothing to do for NULL
+    
+    // Clone the data, relative to ourselves
+    // This creates a new copy -- useable by scripting languages
+    OBGenericData *clone = d->Clone(this);
+    if (clone)
+      _vdata.push_back(clone);
+    
+    return;
+  }
 
   void OBBase::DeleteData(unsigned int dt)
   {
@@ -222,7 +249,7 @@ namespace OpenBabel
 
 
 
-  /*! \mainpage v2.1 API Documentation
+  /*! \mainpage API Documentation
 
   \section base Introduction
  
@@ -235,7 +262,7 @@ namespace OpenBabel
   This documentation outlines the Open Babel programming interface, providing
   information on all public classes, methods, and data. In particular, strives 
   to provide as much (or as little) detail as needed. More information
-  can also be found on the <a href="http://openbabel.sourceforge.net/">
+  can also be found on the <a href="http://openbabel.org/">
   main website</a> and through the <a
   href="mailto:openbabel-discuss@lists.sourceforge.net">openbabel-discuss</a>
   mailing list.
@@ -248,7 +275,9 @@ namespace OpenBabel
      (the most important, widely-used public classes)
   - <a href="annotated.shtml" class="el">All Classes</a> \n
      (all classes with brief descriptions)
-  - \ref changes "What's New in Version 2.1" \n
+  - \ref changes22 "What's New in Version 2.2" \n
+     (changes since 2.1 releases)
+  - \ref changes21 "What's New in Version 2.1" \n
      (changes since 2.0 releases)
   - \ref other "Further Information" \n
      (other resources, tutorials, mailing lists, ...)
@@ -334,7 +363,7 @@ namespace OpenBabel
             // Write SMILES to the standard output
             conv->Write(&mol);
          }
-         return(1); // exit with success
+         return 0; // exit with success
       }
   \endcode
 
@@ -344,7 +373,7 @@ namespace OpenBabel
 
   For a further list of example code, see the 
   <a
-  href="http://openbabel.sourceforge.net/wiki/Developer:Tutorial">developer
+  href="http://openbabel.org/wiki/Developer:Tutorial">developer
   tutorials</a>. This section includes examples in C++, Perl, Python,
   and other porgramming languages.
 
@@ -387,7 +416,35 @@ namespace OpenBabel
   - matrix3x3 - Square 3x3 matrices for 3D transformations and rotations
   - vector3 - 3D vector class for translations and planes
 
-  \page changes What's New in Version 2.1
+  \page changes22 What's New in Version 2.2
+
+  Throughout the API documentation, new classes and methods are
+  indicated with a disclaimer "Since: version 2.2." 
+
+  Several new classes have been introduced, notably
+  - OBPlugin - Cleaner interface to dynamic plugins, including OBFormat
+  OBForceField, OBFingerprint, and the new OBDescriptor and OBOp.
+  - SpaceGroup - Handle crystallographic space group symmetry.
+  - AliasData - Handle atoms which serve as "aliases" for larger fragments
+  for example in drawing programs - "COOH" vs. four atoms for the carboxylic
+  acid. Currently used for MDL 2D files.
+  - OBGridData - Store and process numeric grid data involved with orbitals or 
+  electrostatic potential.
+  - OBBuilder - New class to handle generation of 3D coordinates for SMILES,
+  InChI and other formats.
+  - OBForceField - Revised, improved class, including use of constraints.
+  - OBMoleculeFormat - Installed by default, to facilitate new format development.
+  - OBLocale - New class to ensure chemical data is read in the "C" numeric locale.
+  - OBPhModel - Now accepts pH-dependent transformations.
+
+  In addition, a wide variety of plugins are available, including MMFF94 
+  and UFF force fields, SMARTS-based descriptors for filtering data sets,
+  compound descriptors such as the Lipinsky Rule of Five, and chemical 
+  transformations.
+
+  Optional headers include integration with the Boost Graph Library.
+
+  \page changes21 What's New in Version 2.1
 
   Throughout the API documentation, new classes and methods are
   indicated with a disclaimer "Since: version 2.1." Documentation, in
@@ -402,7 +459,7 @@ namespace OpenBabel
   bonds. Previously only 2^16 atoms or bonds were possible.
 
   The OBNodeBase, OBEdgeBase, and OBGraphBase classes were
-  deprecated. Typedef declarations provide backwards compatibilty by
+  deprecated. Typedef declarations provide backwards compatibility by
   mapping to OBAtom, OBBond, and OBMol, respectively.
 
   In addition, this page gives a general list of additions to the library.
@@ -434,10 +491,10 @@ namespace OpenBabel
   developing with the library.
 
   Open Babel homepage:
-  - <a href="http://openbabel.sourceforge.net/wiki/Develop">Developing with Open Babel</a>
-  - <a href="http://openbabel.sourceforge.net/wiki/Developer:Tutorial">Developer
+  - <a href="http://openbabel.org/wiki/Develop">Developing with Open Babel</a>
+  - <a href="http://openbabel.org/wiki/Developer:Tutorial">Developer
   tutorials</a>
-  - <a href="http://openbabel.sourceforge.net/wiki/Contribute">Contributing
+  - <a href="http://openbabel.org/wiki/Contribute">Contributing
   to the Open Babel project</a>
 
   SourceForge project pages:
