@@ -107,6 +107,7 @@ namespace OpenBabel
       //! Constructor
       explicit OBForceFieldGhemical(const char* ID, bool IsDefault=true) : OBForceField(ID, IsDefault)
       {
+        _validSetup = false;
         _init = false;
         _rvdw = 7.0;
         _rele = 15.0;
@@ -128,7 +129,10 @@ namespace OpenBabel
       }
 
       //!Clone the current instance. May be desirable in multithreaded environments
-      virtual OBForceFieldGhemical* MakeNewInstance(){ return new OBForceFieldGhemical(*this); }
+      virtual OBForceFieldGhemical* MakeNewInstance()
+      { 
+        return new OBForceFieldGhemical(_id, false); 
+      }
 
       //! Get the unit in which the energy is expressed
       std::string GetUnit() 
