@@ -30,7 +30,7 @@ GNU General Public License for more details.
 #include "openbabel/obmolecformat.h"
 
 using namespace std;
-using std::tr1::shared_ptr;
+//using std::tr1::shared_ptr;
 
 namespace OpenBabel
 {
@@ -628,7 +628,10 @@ bool ChemKinFormat::ReadReactionQualifierLines(istream& ifs, OBReaction* pReact)
       //not "END". Has an even number of tokens.
       //3-body efficiencies
       for(int i=0;i<toks.size()-1;++i)//also incremented in body to retrieve id,val pairs
-        pRD->SetEfficiency(toks[i++], atof(toks[i].c_str()));
+      {
+        string sp(toks[i++]);
+        pRD->SetEfficiency(sp, atof(toks[i].c_str()));
+      }
     }
   }
   return ifs!=NULL;
