@@ -411,7 +411,7 @@ namespace OpenBabel
     for(unsigned int k=0; boundedAtomsSerialNumbersValid[k]; k++)
       {
         // Find atom that is connected to, write an error message
-        OBAtom *connectedAtom = 0L;
+        OBAtom *connectedAtom = NULL;
         for (OBAtom *a1 = mol.BeginAtom(i);a1;a1 = mol.NextAtom(i)) {
           // again, atoms may not have residues, but if they do, check serials
           if (a1->GetResidue() != NULL &&
@@ -422,7 +422,7 @@ namespace OpenBabel
               break;
             }
         }
-        if (connectedAtom == 0L)
+        if (connectedAtom == NULL)
           {
             errorMsg << "WARNING: Problems reading a PDB file:\n"
                      << "  Problems reading a CONECT record.\n"
@@ -438,9 +438,11 @@ namespace OpenBabel
 
         // Figure the bond order
         unsigned char order = 0;
-        while(boundedAtomsSerialNumbersValid[k+order+1] && (boundedAtomsSerialNumbers[k+order]
-                                                            == boundedAtomsSerialNumbers[k+order+1]))
+        while(     boundedAtomsSerialNumbersValid[k+order+1] 
+               && (boundedAtomsSerialNumbers[k+order] == boundedAtomsSerialNumbers[k+order+1]) )
+        {
           order++;
+        }
         k += order;
 	
         // Generate the bond
@@ -476,14 +478,66 @@ namespace OpenBabel
         ofs << buffer << endl;
       }
 
-    if (strlen(mol.GetTitle()) > 0)
-      snprintf(buffer, BUFF_SIZE, "COMPND    %s ",mol.GetTitle());
-    else
-      snprintf(buffer, BUFF_SIZE, "COMPND    UNNAMED");
-    ofs << buffer << endl;
+    // write back all fields (REMARKS, HELIX, SHEET, SITE, ...)
+    bool compndWritten = false;
+    bool authorWritten = false;
+    std::vector<OBGenericData*> pairData = mol.GetAllData(OBGenericDataType::PairData);
+    for (std::vector<OBGenericData*>::iterator data = pairData.begin(); data != pairData.end(); ++data) {
+      OBPairData *pd = static_cast<OBPairData*>(*data);
+      string attr = pd->GetAttribute();
+      
+      // filter to make sure we are writing pdb fields only
+      if (attr != "HEADER" && attr != "OBSLTE" && attr != "TITLE" && attr != "SPLIT" &&
+          attr != "CAVEAT" && attr != "COMPND" && attr != "SOURCE" && attr != "KEYWDS" &&
+          attr != "EXPDTA" && attr != "NUMMDL" && attr != "MDLTYP" && attr != "AUTHOR" &&
+          attr != "REVDAT" && attr != "SPRSDE" && attr != "JRNL" && attr != "REMARK" &&
+          attr != "DBREF" && attr != "DBREF1" && attr != "DBREF2" && attr != "SEQADV" &&
+          attr != "SEQRES" && attr != "MODRES" && attr != "HET" && attr != "HETNAM" &&
+          attr != "HETSYN" && attr != "FORMUL" && attr != "HELIX" && attr != "SHEET" &&
+          attr != "SSBOND" && attr != "LINK" && attr != "CISPEP" && attr != "SITE" &&
+          attr != "ORIGX1" && attr != "ORIGX2" && attr != "ORIGX3" && attr != "SCALE1" &&
+          attr != "SCALE2" && attr != "SCALE3" && attr != "MATRIX1" && attr != "MATRIX2" &&
+          attr != "MATRIX3" && attr != "MODEL") 
+        continue;
 
-    snprintf(buffer, BUFF_SIZE, "AUTHOR    GENERATED BY OPEN BABEL %s",BABEL_VERSION);
-    ofs << buffer << endl;
+      if (attr == "COMPND")
+        compndWritten = true;
+      if (attr == "AUTHOR")
+        authorWritten = true;
+
+      // compute spacing needed. HELIX, SITE, HET, ... are trimmed when reading
+      int nSpacing = 6 - attr.size();
+      for (int i = 0; i < nSpacing; ++i)
+        attr += " ";
+
+
+      std::string lines = pd->GetValue();
+      string::size_type last = 0;
+      string::size_type pos = lines.find('\n');
+      while (last != string::npos) {
+        string line = lines.substr(last, pos - last);
+        if (pos == string::npos)
+          last = string::npos;
+        else
+          last = pos + 1;
+        pos = lines.find('\n', last);
+
+        ofs << attr << line << endl;
+      }
+    }
+
+    if (!compndWritten) {
+      if (strlen(mol.GetTitle()) > 0)
+        snprintf(buffer, BUFF_SIZE, "COMPND    %s ",mol.GetTitle());
+      else
+        snprintf(buffer, BUFF_SIZE, "COMPND    UNNAMED");
+      ofs << buffer << endl;
+    }
+
+    if (!authorWritten) {
+      snprintf(buffer, BUFF_SIZE, "AUTHOR    GENERATED BY OPEN BABEL %s",BABEL_VERSION);
+      ofs << buffer << endl;
+    }
 
     // Write CRYST1 record, containing unit cell parameters, space group
     // and Z value (supposed to be 1)
@@ -556,8 +610,8 @@ namespace OpenBabel
               {
                 if (strlen(type_name) < 4)
                   {
-                    char tmp[16];
-                    strncpy(tmp, type_name, 16);
+                    char tmp[10];
+                    strncpy(tmp, type_name, 10);
                     snprintf(padded_name, sizeof(padded_name), " %-3s", tmp);
                     strncpy(type_name,padded_name,4);
                     type_name[4] = '\0';
@@ -622,27 +676,38 @@ namespace OpenBabel
         snprintf(buffer, BUFF_SIZE, "CONECT%5d", i);
         ofs << buffer;
         // Write out up to 4 real bonds per line PR#1711154
-        int currentValence = 0;
+        unsigned int currentValence = 0;
         for (nbr = atom->BeginNbrAtom(k);nbr;nbr = atom->NextNbrAtom(k))
           {
-            snprintf(buffer, BUFF_SIZE, "%5d", nbr->GetIdx());
-            ofs << buffer;
-            if (++currentValence % 4 == 0) {
-              // Add the trailing space to finish this record
-              ofs << "                                       \n";
-              // write the start of a new CONECT record
-              snprintf(buffer, BUFF_SIZE, "CONECT%5d", i);
-              ofs << buffer;              
-            }
+            unsigned int order = mol.GetBond(atom, nbr)->GetBondOrder();
+            unsigned int it_order = 0;
+            for( it_order = 0; it_order < order; it_order++ )
+              {
+                if (0 != currentValence && 0 == currentValence % 4)
+                  {
+                    // Add the trailing space to finish this record
+                    ofs << "                                       \n";
+                    // write the start of a new CONECT record
+                    snprintf(buffer, BUFF_SIZE, "CONECT%5d", i);
+                    ofs << buffer;              
+                  }
+                currentValence++;
+                snprintf(buffer, BUFF_SIZE, "%5d", nbr->GetIdx());
+                ofs << buffer;
+              }
           }
 
         // Add trailing spaces
-        int remainingValence = atom->GetValence() % 4;
-        for (int count = 0; count < (4 - remainingValence); count++) {
-          snprintf(buffer, BUFF_SIZE, "     ");
-          ofs << buffer;
-        }
-        ofs << "                                       \n";
+        unsigned int remainingValence = currentValence % 4;
+        if( 0 < remainingValence )
+          {
+            for (int count = 0; count < (4 - remainingValence); count++) 
+              {
+                snprintf(buffer, BUFF_SIZE, "     ");
+                ofs << buffer;
+              }
+          }
+        ofs << "                                                 \n";
       }
 
     snprintf(buffer, BUFF_SIZE, "MASTER        0    0    0    0    0    0    0    0 ");
