@@ -1,5 +1,5 @@
 /**********************************************************************
-Copyright (C) 2002-2005 by Geoffrey Hutchison
+Copyright (C) 2002-2006 by Geoffrey Hutchison
 Based on code Copyright (C) 1999 Joerg-Ruediger Hill
 Some portions Copyright (C) 2004 by Chris Morley
  
@@ -12,10 +12,9 @@ but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 ***********************************************************************/
+#include <openbabel/babelconfig.h>
 
-#include "mol.h"
-#include "obconversion.h"
-#include "obmolecformat.h"
+#include <openbabel/obmolecformat.h>
 
 using namespace std;
 namespace OpenBabel
@@ -63,7 +62,7 @@ ViewMolFormat theViewMolFormat;
 /////////////////////////////////////////////////////////////////
 bool ViewMolFormat::ReadMolecule(OBBase* pOb, OBConversion* pConv)
 {
-    OBMol* pmol = dynamic_cast<OBMol*>(pOb);
+    OBMol* pmol = pOb->CastAndClear<OBMol>();
     if(pmol==NULL)
         return false;
 
