@@ -324,6 +324,45 @@ namespace OpenBabel
             PropertyScalarsNeeded=0;
           }
       }
+    else if(name=="array" && PropertyScalarsNeeded)
+      {
+        //Read vibrational frequencies and rotational constants from properties
+        xmlTextReaderRead(reader());
+        const xmlChar* pvalue = xmlTextReaderConstValue(reader());
+        string value;
+        if(pvalue)
+          value = (const char*)pvalue;
+        vector<string> items;
+        tokenize(items,value);
+
+        if(titleonproperty.find("vibFreqs")!=string::npos)
+        {
+          vector< vector< vector3 > > vLx;
+          vector<double> vFrequencies, vIntensities;
+          for(unsigned i=0;i<items.size();++i)
+            vFrequencies.push_back(atof(items[i].c_str()));
+
+          OBVibrationData* vd = new OBVibrationData;
+          vd->SetData(vLx, vFrequencies, vIntensities);
+          vd->SetOrigin(fileformatInput);
+          _pmol->SetData(vd);
+        }
+
+        else if(titleonproperty.find("rotConsts")!=string::npos)
+        {
+          const double WAVENUM_TO_GHZ=30.0;
+          vector<double> rotConsts;
+          for(unsigned i=0;i<items.size();++i)
+            rotConsts.push_back(atof(items[i].c_str()) * WAVENUM_TO_GHZ);
+
+          OBRotationData* rd = new OBRotationData;
+          rd->SetData(OBRotationData::UNKNOWN, rotConsts, 1);//rotor type and symmetry number unknown
+          rd->SetOrigin(fileformatInput);
+          _pmol->SetData(rd);
+        }
+
+        PropertyScalarsNeeded = 0;
+      }
     else if(name=="symmetry")
       {
         const xmlChar* pname  = xmlTextReaderGetAttribute(reader(), BAD_CAST "spaceGroup");
@@ -352,7 +391,8 @@ namespace OpenBabel
           ReadNasaThermo();
         else
           {
-            pattr  = (const char*)xmlTextReaderGetAttribute(reader(), BAD_CAST "title");
+            if(!pattr) // no dictRef; look for title on scalar
+              pattr  = (const char*)xmlTextReaderGetAttribute(reader(), BAD_CAST "title");
             if(pattr)
               titleonproperty = pattr;
             else
@@ -444,13 +484,16 @@ namespace OpenBabel
       }
      else if(name=="symmetry")
       {
-        const SpaceGroup *group = SpaceGroup::GetSpaceGroup(SpaceGroupName);
-        if ((!group || !(_SpaceGroup == *group)) && _SpaceGroup.IsValid())
-          group = SpaceGroup::Find(&_SpaceGroup);
-        if (group)
-          pUnitCell->SetSpaceGroup(group);
-        else
-          pUnitCell->SetSpaceGroup(SpaceGroupName);
+        if(!SpaceGroupName.empty())
+        {
+          const SpaceGroup *group = SpaceGroup::GetSpaceGroup(SpaceGroupName);
+          if ((!group || !(_SpaceGroup == *group)) && _SpaceGroup.IsValid())
+            group = SpaceGroup::Find(&_SpaceGroup);
+          if (group)
+            pUnitCell->SetSpaceGroup(group);
+          else
+            pUnitCell->SetSpaceGroup(SpaceGroupName);
+        }
       }
     return true;
   }
@@ -1069,7 +1112,7 @@ namespace OpenBabel
                         "%a %b %d %H:%M:%S %Z %Y",
                         localtime((time_t *) &akttime)
                         );
-    return timestr;
+    return string(timestr);
   }
 
   /////////////////////////////////////////////////////////////
@@ -1831,7 +1874,7 @@ namespace OpenBabel
 
   void CMLFormat::WriteProperties(OBMol& mol, bool& propertyListWritten)
   {
-    // static const xmlChar C_DICTREF[]      = "dictRef";
+    static const xmlChar C_DICTREF[]      = "dictRef";
     static const xmlChar C_PROPERTYLIST[] = "propertyList";
     static const xmlChar C_PROPERTY[]     = "property";
     static const xmlChar C_SCALAR[]       = "scalar";
@@ -1850,10 +1893,15 @@ namespace OpenBabel
                 xmlTextWriterStartElementNS(writer(), prefix, C_PROPERTYLIST, NULL);
                 propertyListWritten=true;
               }
+
             xmlTextWriterStartElementNS(writer(), prefix, C_PROPERTY, NULL);
-            //Title is now on <property>
-            xmlTextWriterWriteFormatAttribute(writer(), C_TITLE,"%s",(*k)->GetAttribute().c_str());
+            //Title is now on <property>. If the attribute name has a namespace, use dictRef instead.
+            string att((*k)->GetAttribute());
+            xmlTextWriterWriteFormatAttribute(writer(), 
+              (att.find(':')==string::npos) ? C_TITLE : C_DICTREF,
+              "%s",att.c_str());
             xmlTextWriterStartElementNS(writer(), prefix, C_SCALAR, NULL);
+
             //Title used to be on <scalar>...
             //xmlTextWriterWriteFormatAttribute(writer(), C_TITLE,"%s",(*k)->GetAttribute().c_str());
             xmlTextWriterWriteFormatString(writer(),"%s", (static_cast<OBPairData*>(*k))->GetValue().c_str());
