@@ -249,7 +249,10 @@ namespace OpenBabel
     OBGenericData("UnitCell", OBGenericDataType::UnitCell),
     _a(0.0), _b(0.0), _c(0.0), _alpha(0.0), _beta(0.0), _gamma(0.0),
     _spaceGroup( NULL ), _lattice(Undefined)
-  {  }
+  {  
+    // We should default to P1 space group unless we know differently
+    SetSpaceGroup(1);
+  }
 
   OBUnitCell::OBUnitCell(const OBUnitCell &src) :
     OBGenericData("UnitCell", OBGenericDataType::UnitCell),
@@ -299,15 +302,37 @@ namespace OpenBabel
   */
   void OBUnitCell::SetData(const vector3 v1, const vector3 v2, const vector3 v3)
   {
-    _a = v1.length();
-    _b = v2.length();
-    _c = v3.length();
-    _alpha = vectorAngle(v2, v3);
-    _beta = vectorAngle(v1, v3);
-    _gamma = vectorAngle(v1, v2);
     _v1 = v1;
     _v2 = v2;
     _v3 = v3;
+
+    _a = _v1.length();
+    _b = _v2.length();
+    _c = _v3.length();
+
+    // For PR#1961604 -- somewhat contrived example
+    if (IsNearZero(_a) && !IsNearZero(_c)) {
+      _v1 = _v3; // we'll reset _v3 below
+      _a = _c;
+      _c = 0.0;
+    }
+
+    // Sanity checks for 1D or 2D translation
+    if (IsNearZero(_b)) { // 1D
+      _v2.Set(v1.y(), -v1.x(), v1.z()); // rotate base vector by 90 degrees
+      _b = 999.999;
+      _v2 = _b * _v2.normalize(); // set to a large displacement
+    }
+
+    if (IsNearZero(_c)) { // 2D or 1D
+      _v3 = cross(_v1, _v2);
+      _c = 999.999;
+      _v3 = _c * _v3.normalize(); // set to a large displacement
+    }
+    
+    _alpha = vectorAngle(_v2, _v3);
+    _beta =  vectorAngle(_v1, _v3);
+    _gamma = vectorAngle(_v1, _v2);
   }
 
   //! Implements <a href="http://qsar.sourceforge.net/dicts/blue-obelisk/index.xhtml#convertNotionalIntoCartesianCoordinates">blue-obelisk:convertNotionalIntoCartesianCoordinates</a>
@@ -316,6 +341,7 @@ namespace OpenBabel
     vector<vector3> v;
     v.reserve(3);
 
+    // no unit cell vectors
     if (IsNegligible(_v1.length(), 1.0, 1.0e-9) &&
         IsNegligible(_v2.length(), 1.0, 1.0e-9) &&
         IsNegligible(_v3.length(), 1.0, 1.0e-9))
@@ -333,8 +359,11 @@ namespace OpenBabel
     else
       {
         v.push_back(_v1);
-        v.push_back(_v2);
-        v.push_back(_v3);
+        // we set these above in case we had a 1D or 2D translation vector system
+        if (fabs(_b - 999.999) > 1.0e-1)
+          v.push_back(_v2);
+        if (fabs(_c - 999.999) > 1.0e-1)
+          v.push_back(_v3);
       }
 
     return v;
@@ -361,11 +390,15 @@ namespace OpenBabel
     return m;
   }
 
+  // Convert from fractional to Cartesian
   //! Implements <a href="http://qsar.sourceforge.net/dicts/blue-obelisk/index.xhtml#calculateOrthogonalisationMatrix">blue-obelisk:calculateOrthogonalisationMatrix</a>
   matrix3x3 OBUnitCell::GetOrthoMatrix()
   {
     matrix3x3 m;
-  
+    if (IsNearZero(_c) || IsNearZero(_b)) {
+      // 1D or 2D unit cell
+    }
+
     // already here, let's not duplicate the work
     m.FillOrth(_alpha, _beta, _gamma, _a, _b, _c);
 
@@ -546,17 +579,40 @@ namespace OpenBabel
     }
     return 0; //presumably never reached
   }
-  
+
+  // Helper function -- transform fractional coordinates to ensure they lie in the unit cell
+  vector3 transformedFractionalCoordinate(vector3 originalCoordinate)
+  {
+    // ensure the fractional coordinate is entirely within the unit cell
+    vector3 returnValue(originalCoordinate);
+
+    // So if we have -2.08, we take -2.08 - (-2) = -0.08 .... almost what we want
+    returnValue.SetX(originalCoordinate.x() - int(originalCoordinate.x()) );
+    returnValue.SetY(originalCoordinate.y() - int(originalCoordinate.y()) );
+    returnValue.SetZ(originalCoordinate.z() - int(originalCoordinate.z()) );
+
+    if (returnValue.x() < 0.0)
+      returnValue.SetX(returnValue.x() + 1.0);
+    if (returnValue.y() < 0.0)
+      returnValue.SetY(returnValue.y() + 1.0);
+    if (returnValue.z() < 0.0)
+      returnValue.SetZ(returnValue.z() + 1.0);
+
+    return returnValue;
+  }
+
   void OBUnitCell::FillUnitCell(OBMol *mol)
   {
     const SpaceGroup *sg = GetSpaceGroup(); // the actual space group and transformations for this unit cell
     
     // For each atom, we loop through: convert the coords back to inverse space, apply the transformations and create new atoms
-    vector3 uniqueV, newV;
+    vector3 uniqueV, newV, updatedCoordinate;
     list<vector3> transformedVectors; // list of symmetry-defined copies of the atom
-    list<vector3>::iterator transformIterator;
+    list<vector3>::iterator transformIterator, duplicateIterator;
     OBAtom *newAtom;
     list<OBAtom*> atoms; // keep the current list of unique atoms -- don't double-create
+    list<vector3> coordinates; // all coordinates to prevent duplicates
+    bool foundDuplicate;
     FOR_ATOMS_OF_MOL(atom, *mol)
       atoms.push_back(&(*atom));
 
@@ -564,24 +620,37 @@ namespace OpenBabel
     for (i = atoms.begin(); i != atoms.end(); ++i) {
       uniqueV = (*i)->GetVector();
       uniqueV *= GetFractionalMatrix();
-        
+      uniqueV = transformedFractionalCoordinate(uniqueV);
+      coordinates.push_back(uniqueV);
+  
       transformedVectors = sg->Transform(uniqueV);
       for (transformIterator = transformedVectors.begin();
            transformIterator != transformedVectors.end(); ++transformIterator) {
         // coordinates are in reciprocal space -- check if it's in the unit cell
-        // TODO: transform these into the unit cell and check for duplicates
-        if (transformIterator->x() < 0.0 || transformIterator->x() > 1.0)
+        // if not, transform it in place
+        updatedCoordinate = transformedFractionalCoordinate(*transformIterator);
+        foundDuplicate = false;
+
+        // Check if the transformed coordinate is a duplicate of an atom
+        for (duplicateIterator = coordinates.begin();
+             duplicateIterator != coordinates.end(); ++duplicateIterator) {
+          if (duplicateIterator->distSq(updatedCoordinate) < 1.0e-4) {
+            foundDuplicate = true;
+            break;
+          }
+        }
+        if (foundDuplicate)
           continue;
-        else if (transformIterator->y() < 0.0 || transformIterator->y() > 1.0)
-          continue;
-        else if (transformIterator->z() < 0.0 || transformIterator->z() > 1.0)
-          continue;
-             
+        
+        coordinates.push_back(updatedCoordinate); // make sure to check the new atom for dupes
         newAtom = mol->NewAtom();
         newAtom->Duplicate(*i);
-        newAtom->SetVector(GetOrthoMatrix() * (*transformIterator));
+        newAtom->SetVector(GetOrthoMatrix() * updatedCoordinate);
       } // end loop of transformed atoms
+      (*i)->SetVector(GetOrthoMatrix() * uniqueV); // move the atom back into the unit cell
     } // end loop of atoms
+
+    SetSpaceGroup(1); // We've now applied the symmetry, so we should act like a P1 unit cell
   }
   
   double OBUnitCell::GetCellVolume()
@@ -593,14 +662,14 @@ namespace OpenBabel
       case Triclinic:
         result = _a * _b * _c 
           * sqrt(1
-                 - SQUARE(cos( _alpha ))
-                 - SQUARE(cos( _beta ))
-                 - SQUARE(cos( _gamma ))
-                 + 2 * cos( _alpha ) * cos( _beta ) * cos( _gamma )
+                 - SQUARE(cos( _alpha * DEG_TO_RAD ))
+                 - SQUARE(cos( _beta * DEG_TO_RAD ))
+                 - SQUARE(cos( _gamma * DEG_TO_RAD ))
+                 + 2 * cos( _alpha * DEG_TO_RAD ) * cos( _beta * DEG_TO_RAD ) * cos( _gamma * DEG_TO_RAD )
                  );
         break;
       case Monoclinic:
-        result = _a * _b * _c * sin( _beta );
+        result = _a * _b * _c * sin( _beta * DEG_TO_RAD );
         break;
       case Orthorhombic:
         result = _a * _b * _c;
@@ -611,10 +680,10 @@ namespace OpenBabel
       case Rhombohedral:
         result = _a * _a * _a
           * sqrt(1
-                 - SQUARE(cos( _alpha ))
-                 - SQUARE(cos( _beta ))
-                 - SQUARE(cos( _gamma ))
-                 + 2 * cos( _alpha ) * cos( _beta ) * cos( _gamma )
+                 - SQUARE(cos( _alpha * DEG_TO_RAD ))
+                 - SQUARE(cos( _beta * DEG_TO_RAD ))
+                 - SQUARE(cos( _gamma * DEG_TO_RAD ))
+                 + 2 * cos( _alpha * DEG_TO_RAD ) * cos( _beta * DEG_TO_RAD ) * cos( _gamma * DEG_TO_RAD )
                  );
         break;
       case Hexagonal:
@@ -770,7 +839,7 @@ namespace OpenBabel
 
   OBRing *OBRingData::NextRing(std::vector<OBRing*>::iterator &i)
   {
-    i = _vr.begin();
+    ++i;
     return((i == _vr.end()) ? (OBRing*)NULL : (OBRing*)*i);
   }
 
@@ -1381,7 +1450,7 @@ void OBVibrationData::SetData(const std::vector< std::vector< vector3 > > & vLx,
 */
 unsigned int OBVibrationData::GetNumberOfFrequencies() const
 {
-  return !this->_vFrequencies.empty() ? this->_vFrequencies.size() - 1 : 0;
+  return !this->_vFrequencies.empty() ? this->_vFrequencies.size() : 0;
 }
 
 } //end namespace OpenBabel
