@@ -677,7 +677,8 @@ namespace OpenBabel {
     string file = filename;
     string::size_type extPos = file.rfind('.');
 
-    if(extPos!=string::npos)
+    if(extPos!=string::npos // period found
+       && (file.substr(extPos + 1, file.size())).find("/")==string::npos) // and period is after the last "/"
       {
         // only do this if we actually can read .gz files
 #ifdef HAVE_LIBZ
@@ -692,7 +693,14 @@ namespace OpenBabel {
 #endif
           return FindFormat( (file.substr(extPos + 1, file.size())).c_str() );
       }
-    return NULL; //if no extension		
+
+    // Check the filename if no extension (e.g. VASP does not use extensions):
+    extPos = file.rfind('/');
+    if(extPos!=string::npos) {
+      return FindFormat( (file.substr(extPos + 1, file.size())).c_str() );
+    }
+    // If we are just passed the filename with no path, this should catch it:
+    return FindFormat( file.c_str() ); //if no format found
   }
 
   OBFormat* OBConversion::FormatFromMIME(const char* MIME)
@@ -741,6 +749,13 @@ namespace OpenBabel {
     // Restore the original C++ locale as well
     pInStream->imbue(originalLocale);
 
+    // If we failed to read, plus the stream is over, then check if this is a stream from ReadFile
+    if (!success && !pInStream->good() && NeedToFreeInStream) {
+      ifstream *inFstream = dynamic_cast<ifstream*>(pInStream);
+      if (inFstream != 0)
+        inFstream->close(); // We will free the stream later, but close the file now
+    }
+
     return success;
   }
 
