@@ -57,8 +57,8 @@ namespace OpenBabel
           int ref[4];
           rotor->GetDihedralAtoms(ref);
           char buffer[BUFF_SIZE];
-          sprintf(buffer,"The rotor has no associated torsion values -> %d %d %d %d",ref[0],ref[1],ref[2],ref[3]);
-
+          snprintf(buffer, BUFF_SIZE, "The rotor has no associated torsion values -> %d %d %d %d",
+		  ref[0],ref[1],ref[2],ref[3]);
           obErrorLog.ThrowError(__FUNCTION__, buffer, obDebug);
         }
 
@@ -562,7 +562,7 @@ namespace OpenBabel
     for (i = _rotor.begin();i != _rotor.end();++i)
       delete *i;
     _rotor.clear();
-    _fix.Clear();
+    //_fix.Clear();
   }
 
   bool CompareRotor(const pair<OBBond*,int> &a,const pair<OBBond*,int> &b)
