@@ -27,7 +27,9 @@ GNU General Public License for more details.
 #include <openbabel/mol.h>
 #include <openbabel/obconversion.h>
 #include <openbabel/forcefield.h>
-#include <unistd.h>
+#ifndef _MSC_VER
+  #include <unistd.h>
+#endif
 
 using namespace std;
 using namespace OpenBabel;
@@ -39,7 +41,12 @@ int main(int argc,char **argv)
   int steps = 2500;
   double crit = 1e-6;
   bool sd = false;
+  bool cut = false;
+  bool newton = false;
   bool hydrogens = false;
+  double rvdw = 6.0;
+  double rele = 10.0;
+  int freq = 10;
   string basename, filename = "", option, option2, ff = "Ghemical";
   char *oext;
   OBConversion conv;
@@ -54,35 +61,66 @@ int main(int argc,char **argv)
     cout << endl;
     cout << "  -cg         use conjugate gradients algorithm (default)" << endl;
     cout << endl;
+    cout << "  -sd         use steepest descent algorithm" << endl;
+    cout << endl;
+    cout << "  -newton     use Newton2Num linesearch (default=Simple)" << endl;
+    cout << endl;
     cout << "  -ff ffid    select a forcefield:" << endl;
     cout << endl;
     cout << "  -h          add hydrogen atoms" << endl;
     cout << endl;
     cout << "  -n steps    specify the maximum numer of steps (default=2500)" << endl;
     cout << endl;
-    cout << "  -o <format> specify the output format" << endl;
+    cout << "  -cut        use cut-off (default=don't use cut-off)" << endl;
     cout << endl;
-    cout << "  -sd         use steepest descent algorithm" << endl;
+    cout << "  -rvdw rvdw  specify the VDW cut-off distance (default=6.0)" << endl;
     cout << endl;
-    FOR_EACH(OBForceField, iter) {
-      //cout << "              " << iter.ID() << " - " << iter.Description() << endl;
-      cout << "              " << iter.ID() << endl;
-    }
+    cout << "  -rele rele  specify the Electrostatic cut-off distance (default=10.0)" << endl;
+    cout << endl;
+    cout << "  -pf freq    specify the frequency to update the non-bonded pairs (default=10)" << endl;
+    cout << endl;
+    OBPlugin::List("forcefields", "verbose");
     exit(-1);
   } else {
     int ifile = 1;
     for (int i = 1; i < argc; i++) {
       option = argv[i];
-      
+
+      // steps
       if ((option == "-n") && (argc > (i+1))) {
         steps = atoi(argv[i+1]);
         ifile += 2;
       }
-
+      // vdw cut-off
+      if ((option == "-rvdw") && (argc > (i+1))) {
+        rvdw = atof(argv[i+1]);
+        ifile += 2;
+      }
+      // ele cut-off
+      if ((option == "-rele") && (argc > (i+1))) {
+        rele = atof(argv[i+1]);
+        ifile += 2;
+      }
+      // pair update frequency
+      if ((option == "-pf") && (argc > (i+1))) {
+        freq = atoi(argv[i+1]);
+        ifile += 2;
+      }
+      // steepest descent
       if (option == "-sd") {
         sd = true;
         ifile++;
       }
+      // enable cut-off
+      if (option == "-cut") {
+        cut = true;
+        ifile++;
+      }
+      // enable Newton2Num
+      if (option == "-newton") {
+        newton = true;
+        ifile++;
+      }
       
       if (strncmp(option.c_str(), "-o", 2) == 0) {
         oext = argv[i] + 2;
@@ -100,8 +138,10 @@ int main(int argc,char **argv)
         ifile++;
       }
 
-      if (option == "-cg")
+      if (option == "-cg") {
+        sd = false;
         ifile++;
+      }
 
       if ((option == "-c") && (argc > (i+1))) {
         crit = atof(argv[i+1]);
@@ -140,6 +180,22 @@ int main(int argc,char **argv)
     exit (-1);
   }
 
+  OBForceField* pFF = OBForceField::FindForceField(ff);
+  if (!pFF) {
+    cerr << program_name << ": could not find forcefield '" << ff << "'." <<endl;
+    exit (-1);
+  }
+ 
+  // set some force field variables
+  pFF->SetLogFile(&cerr);
+  pFF->SetLogLevel(OBFF_LOGLVL_LOW);
+  pFF->SetVDWCutOff(rvdw);    
+  pFF->SetElectrostaticCutOff(rele);    
+  pFF->SetUpdateFrequency(freq);    
+  pFF->EnableCutOff(cut); 
+  if (newton)
+    pFF->SetLineSearchType(LineSearchType::Newton2Num); 
+ 
   OBMol mol;
 
   for (c=1;;c++) {
@@ -151,27 +207,35 @@ int main(int argc,char **argv)
 
     if (hydrogens)
       mol.AddHydrogens();
-
-    OBForceField* pFF = OBForceField::FindForceField(ff);
-    if (!pFF) {
-      cerr << program_name << ": could not find forcefield '" << ff << "'." <<endl;
-      exit (-1);
-    }
- 
-    pFF->SetLogFile(&cout);
-    pFF->SetLogLevel(OBFF_LOGLVL_LOW);
       
     if (!pFF->Setup(mol)) {
       cerr << program_name << ": could not setup force field." << endl;
       exit (-1);
     }
-      
-    if (sd)
-      pFF->SteepestDescent(steps, crit);
-    else
-      pFF->ConjugateGradients(steps, crit);
 
-    pFF->UpdateCoordinates(mol);
+    bool done = true;
+    if (sd) {
+      pFF->SteepestDescentInitialize(steps, crit);
+    } else {
+      pFF->ConjugateGradientsInitialize(steps, crit);
+    }    
+
+    while (done) {
+      if (sd)
+        done = pFF->SteepestDescentTakeNSteps(1);
+      else
+        done = pFF->ConjugateGradientsTakeNSteps(1);
+ 
+      if (pFF->DetectExplosion()) {
+        cerr << "explosion has occured!" << endl;
+        conv.Write(&mol, &cout);
+        return(1);
+      } else
+        pFF->GetCoordinates(mol);
+    }
+    
+
+    pFF->GetCoordinates(mol);
 
     conv.Write(&mol, &cout);
   } // end for loop
